@@ -29,11 +29,14 @@ page.xhtml.t/   0           0     0     644     724       `
 	<body>
 		<main>
 			<h1>Testserver Demo</h1>
-			<p>Simple demo of the testserver. Check the source file for details.</p>
+			<p>Simple demo of the testserver. Check the source file for
+details.</p>
 		</main>
 		<footer>
 			<hr />
-			<p>The contents of this webpage are licensed under a <a rel="license" href="https://creativecommons.org/licenses/by-sa/4.0/">Creative Commons Attribution-ShareAlike 4.0 International License</a>.</p>
+			<p>The contents of this webpage are licensed under a <a
+rel="license" href="https://creativecommons.org/licenses/by-sa/4.0/">Creative
+Commons Attribution-ShareAlike 4.0 International License</a>.</p>
 		</footer>
 	</body>
 </html>
@@ -44,9 +47,11 @@ iVBORw0KGgoAAAANSUhEUgAAABAAAAAQAQAAAAA3iMLMAAAAH0lEQVR4nGP4/59hbyPD3L1QtBaG
 tsLQThgCKvv/HwAu9hd9OeN5mQAAAABJRU5ErkJggg==
 "###;
 
+use testserver::{IP, serve};
+
 fn main() {
-    let server = testserver::serve(DEMO);
-    println!("Listening on http://127.74.137.226:{}/page.xhtml", server.port());
+    let server = serve(DEMO);
+    println!("Listening on http://{}:{}/page.xhtml", IP, server.port());
     println!("Type anything to exit.");
     let _ = std::io::stdin().read_line(&mut String::new());
     drop(server);
